# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/shared/v1alpha/options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/shared/v1alpha/options.proto\x12\x16kaskada.shared.v1alpha\x1a google/protobuf/descriptor.proto:=\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08R\tsensitiveB\xf1\x01\n\x1a\x63om.kaskada.shared.v1alphaB\x0cOptionsProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\xa2\x02\x03KSX\xaa\x02\x16Kaskada.Shared.V1alpha\xca\x02\x16Kaskada\\Shared\\V1alpha\xe2\x02\"Kaskada\\Shared\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Shared::V1alphab\x06proto3')


SENSITIVE_FIELD_NUMBER = 50000
sensitive = DESCRIPTOR.extensions_by_name['sensitive']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(sensitive)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.shared.v1alphaB\014OptionsProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/shared/v1alpha;sharedv1alpha\242\002\003KSX\252\002\026Kaskada.Shared.V1alpha\312\002\026Kaskada\\Shared\\V1alpha\342\002\"Kaskada\\Shared\\V1alpha\\GPBMetadata\352\002\030Kaskada::Shared::V1alpha'
# @@protoc_insertion_point(module_scope)
