# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/credential.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/api/v1alpha/credential.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\x1a$kaskada/shared/v1alpha/options.proto\"\x16\n\x14GetCredentialRequest\"\xad\x01\n\x15GetCredentialResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12)\n\rclient_secret\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x0c\x63lientSecret\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x8e\x01\n\x11\x43redentialService\x12y\n\x03Get\x12).kaskada.api.v1alpha.GetCredentialRequest\x1a*.kaskada.api.v1alpha.GetCredentialResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1alpha/credentialB\xdf\x01\n\x17\x63om.kaskada.api.v1alphaB\x0f\x43redentialProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_GETCREDENTIALREQUEST = DESCRIPTOR.message_types_by_name['GetCredentialRequest']
_GETCREDENTIALRESPONSE = DESCRIPTOR.message_types_by_name['GetCredentialResponse']
GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)

_CREDENTIALSERVICE = DESCRIPTOR.services_by_name['CredentialService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\017CredentialProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _GETCREDENTIALRESPONSE.fields_by_name['client_secret']._options = None
  _GETCREDENTIALRESPONSE.fields_by_name['client_secret']._serialized_options = b'\200\265\030\001'
  _CREDENTIALSERVICE.methods_by_name['Get']._options = None
  _CREDENTIALSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\025\022\023/v1alpha/credential'
  _GETCREDENTIALREQUEST._serialized_start=163
  _GETCREDENTIALREQUEST._serialized_end=185
  _GETCREDENTIALRESPONSE._serialized_start=188
  _GETCREDENTIALRESPONSE._serialized_end=361
  _CREDENTIALSERVICE._serialized_start=364
  _CREDENTIALSERVICE._serialized_end=506
# @@protoc_insertion_point(module_scope)
