# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/test_cases.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$kaskada/api/v1alpha/test_cases.proto\x12\x13kaskada.api.v1alpha\x1a$kaskada/shared/v1alpha/options.proto\"\xf8\x08\n\x0eRedactTestCase\x12&\n\x0froot_safe_value\x18\x01 \x01(\tR\rrootSafeValue\x12\x36\n\x14root_sensitive_value\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x12rootSensitiveValue\x12@\n\x19repeated_sensitive_values\x18\x03 \x03(\tB\x04\x80\xb5\x18\x01R\x17repeatedSensitiveValues\x12\x64\n\x14root_embedded_object\x18\x04 \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x12rootEmbeddedObject\x12l\n\x18repeated_embedded_object\x18\x05 \x03(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x16repeatedEmbeddedObject\x12+\n\x11one_of_safe_value\x18\x07 \x01(\tH\x00R\x0eoneOfSafeValue\x12;\n\x16one_of_sensitive_value\x18\x08 \x01(\tB\x04\x80\xb5\x18\x01H\x00R\x13oneOfSensitiveValue\x12g\n\x15one_of_embedded_value\x18\t \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectH\x00R\x12oneOfEmbeddedValue\x12s\n\x14map_sensitive_values\x18\n \x03(\x0b\x32;.kaskada.api.v1alpha.RedactTestCase.MapSensitiveValuesEntryB\x04\x80\xb5\x18\x01R\x12mapSensitiveValues\x12m\n\x14map_embedded_objects\x18\x0b \x03(\x0b\x32;.kaskada.api.v1alpha.RedactTestCase.MapEmbeddedObjectsEntryR\x12mapEmbeddedObjects\x1a\x45\n\x17MapSensitiveValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1ay\n\x17MapEmbeddedObjectsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.kaskada.api.v1alpha.RedactTestCase.EmbeddedObjectR\x05value:\x02\x38\x01\x1a\x62\n\x0e\x45mbeddedObject\x12\x1f\n\x0bsafe_string\x18\x01 \x01(\tR\nsafeString\x12/\n\x10sensitive_string\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01R\x0fsensitiveStringB\r\n\x0bone_of_testJ\x04\x08\x06\x10\x07\x42\xde\x01\n\x17\x63om.kaskada.api.v1alphaB\x0eTestCasesProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_REDACTTESTCASE = DESCRIPTOR.message_types_by_name['RedactTestCase']
_REDACTTESTCASE_MAPSENSITIVEVALUESENTRY = _REDACTTESTCASE.nested_types_by_name['MapSensitiveValuesEntry']
_REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY = _REDACTTESTCASE.nested_types_by_name['MapEmbeddedObjectsEntry']
_REDACTTESTCASE_EMBEDDEDOBJECT = _REDACTTESTCASE.nested_types_by_name['EmbeddedObject']
RedactTestCase = _reflection.GeneratedProtocolMessageType('RedactTestCase', (_message.Message,), {

  'MapSensitiveValuesEntry' : _reflection.GeneratedProtocolMessageType('MapSensitiveValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.MapSensitiveValuesEntry)
    })
  ,

  'MapEmbeddedObjectsEntry' : _reflection.GeneratedProtocolMessageType('MapEmbeddedObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.MapEmbeddedObjectsEntry)
    })
  ,

  'EmbeddedObject' : _reflection.GeneratedProtocolMessageType('EmbeddedObject', (_message.Message,), {
    'DESCRIPTOR' : _REDACTTESTCASE_EMBEDDEDOBJECT,
    '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase.EmbeddedObject)
    })
  ,
  'DESCRIPTOR' : _REDACTTESTCASE,
  '__module__' : 'kaskada.api.v1alpha.test_cases_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RedactTestCase)
  })
_sym_db.RegisterMessage(RedactTestCase)
_sym_db.RegisterMessage(RedactTestCase.MapSensitiveValuesEntry)
_sym_db.RegisterMessage(RedactTestCase.MapEmbeddedObjectsEntry)
_sym_db.RegisterMessage(RedactTestCase.EmbeddedObject)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\016TestCasesProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._options = None
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_options = b'8\001'
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._options = None
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_options = b'8\001'
  _REDACTTESTCASE_EMBEDDEDOBJECT.fields_by_name['sensitive_string']._options = None
  _REDACTTESTCASE_EMBEDDEDOBJECT.fields_by_name['sensitive_string']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['root_sensitive_value']._options = None
  _REDACTTESTCASE.fields_by_name['root_sensitive_value']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['repeated_sensitive_values']._options = None
  _REDACTTESTCASE.fields_by_name['repeated_sensitive_values']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['one_of_sensitive_value']._options = None
  _REDACTTESTCASE.fields_by_name['one_of_sensitive_value']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE.fields_by_name['map_sensitive_values']._options = None
  _REDACTTESTCASE.fields_by_name['map_sensitive_values']._serialized_options = b'\200\265\030\001'
  _REDACTTESTCASE._serialized_start=100
  _REDACTTESTCASE._serialized_end=1244
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_start=931
  _REDACTTESTCASE_MAPSENSITIVEVALUESENTRY._serialized_end=1000
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_start=1002
  _REDACTTESTCASE_MAPEMBEDDEDOBJECTSENTRY._serialized_end=1123
  _REDACTTESTCASE_EMBEDDEDOBJECT._serialized_start=1125
  _REDACTTESTCASE_EMBEDDEDOBJECT._serialized_end=1223
# @@protoc_insertion_point(module_scope)
