# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/puffin/v1alpha/iceberg_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.shared.v1alpha import catalog_pb2 as kaskada_dot_shared_dot_v1alpha_dot_catalog__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/puffin/v1alpha/iceberg_table.proto\x12\x16kaskada.puffin.v1alpha\x1a\x1egoogle/protobuf/wrappers.proto\x1a$kaskada/shared/v1alpha/catalog.proto\"~\n\x0cIcebergTable\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12<\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\"{\n\x11IcebergTableFiles\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12<\n\x0bsnapshot_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\x12\x14\n\x05paths\x18\x03 \x03(\tR\x05paths\"\x91\x01\n\x0fGetTableRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12L\n\x0e\x63\x61talog_config\x18\x03 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\"N\n\x10GetTableResponse\x12:\n\x05table\x18\x01 \x01(\x0b\x32$.kaskada.puffin.v1alpha.IcebergTableR\x05table\"\xd4\x01\n\x14GetTableFilesRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12<\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nsnapshotId\x12L\n\x0e\x63\x61talog_config\x18\x04 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\"X\n\x15GetTableFilesResponse\x12?\n\x05table\x18\x01 \x01(\x0b\x32).kaskada.puffin.v1alpha.IcebergTableFilesR\x05table\"\x7f\n\x11ListTablesRequest\x12L\n\x0e\x63\x61talog_config\x18\x01 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\rcatalogConfig\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\"R\n\x12ListTablesResponse\x12<\n\x06tables\x18\x01 \x03(\x0b\x32$.kaskada.puffin.v1alpha.IcebergTableR\x06tables2\xc6\x02\n\x0cTableService\x12\x65\n\nListTables\x12).kaskada.puffin.v1alpha.ListTablesRequest\x1a*.kaskada.puffin.v1alpha.ListTablesResponse\"\x00\x12_\n\x08GetTable\x12\'.kaskada.puffin.v1alpha.GetTableRequest\x1a(.kaskada.puffin.v1alpha.GetTableResponse\"\x00\x12n\n\rGetTableFiles\x12,.kaskada.puffin.v1alpha.GetTableFilesRequest\x1a-.kaskada.puffin.v1alpha.GetTableFilesResponse\"\x00\x42\xf6\x01\n\x1a\x63om.kaskada.puffin.v1alphaB\x11IcebergTableProtoP\x01ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/puffin/v1alpha;puffinv1alpha\xa2\x02\x03KPX\xaa\x02\x16Kaskada.Puffin.V1alpha\xca\x02\x16Kaskada\\Puffin\\V1alpha\xe2\x02\"Kaskada\\Puffin\\V1alpha\\GPBMetadata\xea\x02\x18Kaskada::Puffin::V1alphab\x06proto3')



_ICEBERGTABLE = DESCRIPTOR.message_types_by_name['IcebergTable']
_ICEBERGTABLEFILES = DESCRIPTOR.message_types_by_name['IcebergTableFiles']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_GETTABLEFILESREQUEST = DESCRIPTOR.message_types_by_name['GetTableFilesRequest']
_GETTABLEFILESRESPONSE = DESCRIPTOR.message_types_by_name['GetTableFilesResponse']
_LISTTABLESREQUEST = DESCRIPTOR.message_types_by_name['ListTablesRequest']
_LISTTABLESRESPONSE = DESCRIPTOR.message_types_by_name['ListTablesResponse']
IcebergTable = _reflection.GeneratedProtocolMessageType('IcebergTable', (_message.Message,), {
  'DESCRIPTOR' : _ICEBERGTABLE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.IcebergTable)
  })
_sym_db.RegisterMessage(IcebergTable)

IcebergTableFiles = _reflection.GeneratedProtocolMessageType('IcebergTableFiles', (_message.Message,), {
  'DESCRIPTOR' : _ICEBERGTABLEFILES,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.IcebergTableFiles)
  })
_sym_db.RegisterMessage(IcebergTableFiles)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

GetTableFilesRequest = _reflection.GeneratedProtocolMessageType('GetTableFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEFILESREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableFilesRequest)
  })
_sym_db.RegisterMessage(GetTableFilesRequest)

GetTableFilesResponse = _reflection.GeneratedProtocolMessageType('GetTableFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEFILESRESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.GetTableFilesResponse)
  })
_sym_db.RegisterMessage(GetTableFilesResponse)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.puffin.v1alpha.iceberg_table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.puffin.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

_TABLESERVICE = DESCRIPTOR.services_by_name['TableService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.kaskada.puffin.v1alphaB\021IcebergTableProtoP\001ZKgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/puffin/v1alpha;puffinv1alpha\242\002\003KPX\252\002\026Kaskada.Puffin.V1alpha\312\002\026Kaskada\\Puffin\\V1alpha\342\002\"Kaskada\\Puffin\\V1alpha\\GPBMetadata\352\002\030Kaskada::Puffin::V1alpha'
  _ICEBERGTABLE._serialized_start=140
  _ICEBERGTABLE._serialized_end=266
  _ICEBERGTABLEFILES._serialized_start=268
  _ICEBERGTABLEFILES._serialized_end=391
  _GETTABLEREQUEST._serialized_start=394
  _GETTABLEREQUEST._serialized_end=539
  _GETTABLERESPONSE._serialized_start=541
  _GETTABLERESPONSE._serialized_end=619
  _GETTABLEFILESREQUEST._serialized_start=622
  _GETTABLEFILESREQUEST._serialized_end=834
  _GETTABLEFILESRESPONSE._serialized_start=836
  _GETTABLEFILESRESPONSE._serialized_end=924
  _LISTTABLESREQUEST._serialized_start=926
  _LISTTABLESREQUEST._serialized_end=1053
  _LISTTABLESRESPONSE._serialized_start=1055
  _LISTTABLESRESPONSE._serialized_end=1137
  _TABLESERVICE._serialized_start=1140
  _TABLESERVICE._serialized_end=1466
# @@protoc_insertion_point(module_scope)
