# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/materialization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import compute_pb2 as kaskada_dot_api_dot_v1alpha_dot_compute__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)kaskada/api/v1alpha/materialization.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/api/v1alpha/compute.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\x8e\x05\n\x0fMaterialization\x12\x32\n\x12materialization_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12<\n\nwith_views\x18\x05 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\tredis_a_i\x18\x06 \x01(\x0b\x32,.kaskada.api.v1alpha.Materialization.RedisAIH\x00R\x07redisAI\x12\x39\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x12>\n\x08\x61nalysis\x18\t \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisB\x03\xe0\x41\x03R\x08\x61nalysis\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04portB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xe6\x01\n\x1cListMaterializationsResponse\x12P\n\x10materializations\x18\x01 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xba\x01\n\x1aGetMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"n\n\x1c\x43reateMaterializationRequest\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\"\xf8\x01\n\x1d\x43reateMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"s\n\x1d\x44\x65leteMaterializationResponse\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetailsJ\x04\x08\x01\x10\x02\x32\xdf\x05\n\x16MaterializationService\x12\x9e\x01\n\x14ListMaterializations\x12\x30.kaskada.api.v1alpha.ListMaterializationsRequest\x1a\x31.kaskada.api.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb1\x01\n\x12GetMaterialization\x12..kaskada.api.v1alpha.GetMaterializationRequest\x1a/.kaskada.api.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xb2\x01\n\x15\x43reateMaterialization\x12\x31.kaskada.api.v1alpha.CreateMaterializationRequest\x1a\x32.kaskada.api.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,:\x0fmaterialization\"\x19/v1alpha/materializations\x12\xba\x01\n\x15\x44\x65leteMaterialization\x12\x31.kaskada.api.v1alpha.DeleteMaterializationRequest\x1a\x32.kaskada.api.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}B\xe4\x01\n\x17\x63om.kaskada.api.v1alphaB\x14MaterializationProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_MATERIALIZATION = DESCRIPTOR.message_types_by_name['Materialization']
_MATERIALIZATION_REDISAI = _MATERIALIZATION.nested_types_by_name['RedisAI']
_LISTMATERIALIZATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListMaterializationsRequest']
_LISTMATERIALIZATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListMaterializationsResponse']
_GETMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['GetMaterializationRequest']
_GETMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetMaterializationResponse']
_CREATEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateMaterializationRequest']
_CREATEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateMaterializationResponse']
_DELETEMATERIALIZATIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest']
_DELETEMATERIALIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse']
Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization.RedisAI)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.RedisAI)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)

_MATERIALIZATIONSERVICE = DESCRIPTOR.services_by_name['MaterializationService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\024MaterializationProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _MATERIALIZATION_REDISAI.fields_by_name['db']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['db']._serialized_options = b'\372B\006\032\004\030\017(\000'
  _MATERIALIZATION_REDISAI.fields_by_name['host']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION_REDISAI.fields_by_name['port']._options = None
  _MATERIALIZATION_REDISAI.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _MATERIALIZATION.fields_by_name['materialization_id']._options = None
  _MATERIALIZATION.fields_by_name['materialization_id']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['materialization_name']._options = None
  _MATERIALIZATION.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATION.fields_by_name['create_time']._options = None
  _MATERIALIZATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['schema']._options = None
  _MATERIALIZATION.fields_by_name['schema']._serialized_options = b'\340A\003'
  _MATERIALIZATION.fields_by_name['analysis']._options = None
  _MATERIALIZATION.fields_by_name['analysis']._serialized_options = b'\340A\003'
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
  _DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._serialized_options = b'\372B\004r\002\020\001'
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['ListMaterializations']._serialized_options = b'\202\323\344\223\002\033\022\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['GetMaterialization']._serialized_options = b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['CreateMaterialization']._serialized_options = b'\202\323\344\223\002,:\017materialization\"\031/v1alpha/materializations'
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._options = None
  _MATERIALIZATIONSERVICE.methods_by_name['DeleteMaterialization']._serialized_options = b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}'
  _MATERIALIZATION._serialized_start=329
  _MATERIALIZATION._serialized_end=983
  _MATERIALIZATION_REDISAI._serialized_start=870
  _MATERIALIZATION_REDISAI._serialized_end=968
  _LISTMATERIALIZATIONSREQUEST._serialized_start=985
  _LISTMATERIALIZATIONSREQUEST._serialized_end=1110
  _LISTMATERIALIZATIONSRESPONSE._serialized_start=1113
  _LISTMATERIALIZATIONSRESPONSE._serialized_end=1343
  _GETMATERIALIZATIONREQUEST._serialized_start=1345
  _GETMATERIALIZATIONREQUEST._serialized_end=1432
  _GETMATERIALIZATIONRESPONSE._serialized_start=1435
  _GETMATERIALIZATIONRESPONSE._serialized_end=1621
  _CREATEMATERIALIZATIONREQUEST._serialized_start=1623
  _CREATEMATERIALIZATIONREQUEST._serialized_end=1733
  _CREATEMATERIALIZATIONRESPONSE._serialized_start=1736
  _CREATEMATERIALIZATIONRESPONSE._serialized_end=1984
  _DELETEMATERIALIZATIONREQUEST._serialized_start=1986
  _DELETEMATERIALIZATIONREQUEST._serialized_end=2076
  _DELETEMATERIALIZATIONRESPONSE._serialized_start=2078
  _DELETEMATERIALIZATIONRESPONSE._serialized_end=2193
  _MATERIALIZATIONSERVICE._serialized_start=2196
  _MATERIALIZATIONSERVICE._serialized_end=2931
# @@protoc_insertion_point(module_scope)
