# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.errdetails.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.shared.v1alpha import options_pb2 as kaskada_dot_shared_dot_v1alpha_dot_options__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n kaskada/api/v1alpha/shared.proto\x12\x13kaskada.api.v1alpha\x1a\x31kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x1a$kaskada/shared/v1alpha/options.proto\x1a\x17validate/validate.proto\"\xc7\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12V\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32+.kaskada.errdetails.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\x12\x1d\n\nfree_names\x18\x04 \x03(\tR\tfreeNames\"\xf2\x01\n\rAWSCredential\x12M\n\naccess_key\x18\x01 \x01(\x0b\x32,.kaskada.api.v1alpha.AWSCredential.AccessKeyH\x00R\taccessKey\x1a\x7f\n\tAccessKey\x12\x32\n\x11\x61ws_access_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0e\x61wsAccessKeyId\x12>\n\x15\x61ws_secret_access_key\x18\x02 \x01(\tB\x0b\xfa\x42\x04r\x02\x10\x01\x80\xb5\x18\x01R\x12\x61wsSecretAccessKeyB\x11\n\ncredential\x12\x03\xf8\x42\x01\"\xfc\x02\n\x0e\x45xternalS3File\x12;\n\x14virtual_hosted_style\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x12virtualHostedStyle\x12\x61\n\x11\x62ucket_region_key\x18\x02 \x01(\x0b\x32\x33.kaskada.api.v1alpha.ExternalS3File.BucketRegionKeyH\x00R\x0f\x62ucketRegionKey\x12I\n\x0e\x61ws_credential\x18\x10 \x01(\x0b\x32\".kaskada.api.v1alpha.AWSCredentialR\rawsCredential\x1an\n\x0f\x42ucketRegionKey\x12\x1f\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x62ucket\x12\x1f\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06region\x12\x19\n\x03key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03keyB\x0f\n\x08location\x12\x03\xf8\x42\x01\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestIdB\xdb\x01\n\x17\x63om.kaskada.api.v1alphaB\x0bSharedProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_ANALYSIS = DESCRIPTOR.message_types_by_name['Analysis']
_AWSCREDENTIAL = DESCRIPTOR.message_types_by_name['AWSCredential']
_AWSCREDENTIAL_ACCESSKEY = _AWSCREDENTIAL.nested_types_by_name['AccessKey']
_EXTERNALS3FILE = DESCRIPTOR.message_types_by_name['ExternalS3File']
_EXTERNALS3FILE_BUCKETREGIONKEY = _EXTERNALS3FILE.nested_types_by_name['BucketRegionKey']
_REQUESTDETAILS = DESCRIPTOR.message_types_by_name['RequestDetails']
Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

AWSCredential = _reflection.GeneratedProtocolMessageType('AWSCredential', (_message.Message,), {

  'AccessKey' : _reflection.GeneratedProtocolMessageType('AccessKey', (_message.Message,), {
    'DESCRIPTOR' : _AWSCREDENTIAL_ACCESSKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential.AccessKey)
    })
  ,
  'DESCRIPTOR' : _AWSCREDENTIAL,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential)
  })
_sym_db.RegisterMessage(AWSCredential)
_sym_db.RegisterMessage(AWSCredential.AccessKey)

ExternalS3File = _reflection.GeneratedProtocolMessageType('ExternalS3File', (_message.Message,), {

  'BucketRegionKey' : _reflection.GeneratedProtocolMessageType('BucketRegionKey', (_message.Message,), {
    'DESCRIPTOR' : _EXTERNALS3FILE_BUCKETREGIONKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File.BucketRegionKey)
    })
  ,
  'DESCRIPTOR' : _EXTERNALS3FILE,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File)
  })
_sym_db.RegisterMessage(ExternalS3File)
_sym_db.RegisterMessage(ExternalS3File.BucketRegionKey)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\013SharedProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._options = None
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._options = None
  _AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._serialized_options = b'\372B\004r\002\020\001\200\265\030\001'
  _AWSCREDENTIAL.oneofs_by_name['credential']._options = None
  _AWSCREDENTIAL.oneofs_by_name['credential']._serialized_options = b'\370B\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._options = None
  _EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALS3FILE.oneofs_by_name['location']._options = None
  _EXTERNALS3FILE.oneofs_by_name['location']._serialized_options = b'\370B\001'
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._options = None
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._serialized_options = b'\372B\004r\002\020\001'
  _ANALYSIS._serialized_start=172
  _ANALYSIS._serialized_end=371
  _AWSCREDENTIAL._serialized_start=374
  _AWSCREDENTIAL._serialized_end=616
  _AWSCREDENTIAL_ACCESSKEY._serialized_start=470
  _AWSCREDENTIAL_ACCESSKEY._serialized_end=597
  _EXTERNALS3FILE._serialized_start=619
  _EXTERNALS3FILE._serialized_end=999
  _EXTERNALS3FILE_BUCKETREGIONKEY._serialized_start=872
  _EXTERNALS3FILE_BUCKETREGIONKEY._serialized_end=982
  _REQUESTDETAILS._serialized_start=1001
  _REQUESTDETAILS._serialized_end=1048
# @@protoc_insertion_point(module_scope)
