# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/errdetails/v1alpha/fenl_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x12\x1akaskada.errdetails.v1alpha\"\x87\x01\n\x0f\x46\x65nlDiagnostics\x12U\n\x10\x66\x65nl_diagnostics\x18\x01 \x03(\x0b\x32*.kaskada.errdetails.v1alpha.FenlDiagnosticR\x0f\x66\x65nlDiagnostics\x12\x1d\n\nnum_errors\x18\x02 \x01(\x03R\tnumErrors\"\xc7\x01\n\x0e\x46\x65nlDiagnostic\x12@\n\x08severity\x18\x01 \x01(\x0e\x32$.kaskada.errdetails.v1alpha.SeverityR\x08severity\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\'\n\x0fsource_location\x18\x04 \x01(\tR\x0esourceLocation\x12\x1c\n\tformatted\x18\x05 \x01(\tR\tformatted*\x86\x01\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x10\n\x0cSEVERITY_BUG\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03\x12\x11\n\rSEVERITY_NOTE\x10\x04\x12\x11\n\rSEVERITY_HELP\x10\x05\x42\x95\x02\n\x1e\x63om.kaskada.errdetails.v1alphaB\x14\x46\x65nlDiagnosticsProtoP\x01ZSgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha;errdetailsv1alpha\xa2\x02\x03KEX\xaa\x02\x1aKaskada.Errdetails.V1alpha\xca\x02\x1aKaskada\\Errdetails\\V1alpha\xe2\x02&Kaskada\\Errdetails\\V1alpha\\GPBMetadata\xea\x02\x1cKaskada::Errdetails::V1alphab\x06proto3')

_SEVERITY = DESCRIPTOR.enum_types_by_name['Severity']
Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
SEVERITY_UNSPECIFIED = 0
SEVERITY_BUG = 1
SEVERITY_ERROR = 2
SEVERITY_WARNING = 3
SEVERITY_NOTE = 4
SEVERITY_HELP = 5


_FENLDIAGNOSTICS = DESCRIPTOR.message_types_by_name['FenlDiagnostics']
_FENLDIAGNOSTIC = DESCRIPTOR.message_types_by_name['FenlDiagnostic']
FenlDiagnostics = _reflection.GeneratedProtocolMessageType('FenlDiagnostics', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTICS,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostics)
  })
_sym_db.RegisterMessage(FenlDiagnostics)

FenlDiagnostic = _reflection.GeneratedProtocolMessageType('FenlDiagnostic', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTIC,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostic)
  })
_sym_db.RegisterMessage(FenlDiagnostic)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.kaskada.errdetails.v1alphaB\024FenlDiagnosticsProtoP\001ZSgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha;errdetailsv1alpha\242\002\003KEX\252\002\032Kaskada.Errdetails.V1alpha\312\002\032Kaskada\\Errdetails\\V1alpha\342\002&Kaskada\\Errdetails\\V1alpha\\GPBMetadata\352\002\034Kaskada::Errdetails::V1alpha'
  _SEVERITY._serialized_start=422
  _SEVERITY._serialized_end=556
  _FENLDIAGNOSTICS._serialized_start=82
  _FENLDIAGNOSTICS._serialized_end=217
  _FENLDIAGNOSTIC._serialized_start=220
  _FENLDIAGNOSTIC._serialized_end=419
# @@protoc_insertion_point(module_scope)
