# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.api.v1alpha import materialization_pb2 as kaskada_dot_api_dot_v1alpha_dot_materialization__pb2
from kaskada.api.v1alpha import table_pb2 as kaskada_dot_api_dot_v1alpha_dot_table__pb2
from kaskada.api.v1alpha import view_pb2 as kaskada_dot_api_dot_v1alpha_dot_view__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ekaskada/api/v1alpha/spec.proto\x12\x13kaskada.api.v1alpha\x1a)kaskada/api/v1alpha/materialization.proto\x1a\x1fkaskada/api/v1alpha/table.proto\x1a\x1ekaskada/api/v1alpha/view.proto\"\xbd\x01\n\x04Spec\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12/\n\x05views\x18\x02 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x05views\x12P\n\x10materializations\x18\x03 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializationsB\xd9\x01\n\x17\x63om.kaskada.api.v1alphaB\tSpecProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_SPEC = DESCRIPTOR.message_types_by_name['Spec']
Spec = _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
  'DESCRIPTOR' : _SPEC,
  '__module__' : 'kaskada.api.v1alpha.spec_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Spec)
  })
_sym_db.RegisterMessage(Spec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\tSpecProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _SPEC._serialized_start=164
  _SPEC._serialized_end=353
# @@protoc_insertion_point(module_scope)
