# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/staged_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%kaskada/api/v1alpha/staged_file.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a kaskada/api/v1alpha/shared.proto\x1a\x17validate/validate.proto\"\xfa\x02\n\nStagedFile\x12\x1c\n\x07\x66ile_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x06\x66ileId\x12$\n\tfile_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x66ileName\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12S\n\x15upload_completed_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x13uploadCompletedTime\x12*\n\ncontent_id\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01 \xd0\x01\x01R\tcontentId\x12*\n\x0e\x63ontent_length\x18\x06 \x01(\x03\x42\x03\xe0\x41\x03R\rcontentLength\x12\x39\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\"x\n\x16ListStagedFilesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc6\x01\n\x17ListStagedFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x05\x66iles\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"8\n\x14GetStagedFileRequest\x12 \n\x07\x66ile_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x66ileId\"\x9a\x01\n\x15GetStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"X\n\x17\x43reateStagedFileRequest\x12=\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04\x66ile\"\xaf\x01\n\x18\x43reateStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xcc\x03\n\x11StagedFileService\x12\x8b\x01\n\x0fListStagedFiles\x12+.kaskada.api.v1alpha.ListStagedFilesRequest\x1a,.kaskada.api.v1alpha.ListStagedFilesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1alpha/staged_files\x12\x91\x01\n\rGetStagedFile\x12).kaskada.api.v1alpha.GetStagedFileRequest\x1a*.kaskada.api.v1alpha.GetStagedFileResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1alpha/staged_files/{file_id=*}\x12\x94\x01\n\x10\x43reateStagedFile\x12,.kaskada.api.v1alpha.CreateStagedFileRequest\x1a-.kaskada.api.v1alpha.CreateStagedFileResponse\"#\x82\xd3\xe4\x93\x02\x1d:\x04\x66ile\"\x15/v1alpha/staged_filesB\xdf\x01\n\x17\x63om.kaskada.api.v1alphaB\x0fStagedFileProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_STAGEDFILE = DESCRIPTOR.message_types_by_name['StagedFile']
_LISTSTAGEDFILESREQUEST = DESCRIPTOR.message_types_by_name['ListStagedFilesRequest']
_LISTSTAGEDFILESRESPONSE = DESCRIPTOR.message_types_by_name['ListStagedFilesResponse']
_GETSTAGEDFILEREQUEST = DESCRIPTOR.message_types_by_name['GetStagedFileRequest']
_GETSTAGEDFILERESPONSE = DESCRIPTOR.message_types_by_name['GetStagedFileResponse']
_CREATESTAGEDFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateStagedFileRequest']
_CREATESTAGEDFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateStagedFileResponse']
StagedFile = _reflection.GeneratedProtocolMessageType('StagedFile', (_message.Message,), {
  'DESCRIPTOR' : _STAGEDFILE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.StagedFile)
  })
_sym_db.RegisterMessage(StagedFile)

ListStagedFilesRequest = _reflection.GeneratedProtocolMessageType('ListStagedFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesRequest)
  })
_sym_db.RegisterMessage(ListStagedFilesRequest)

ListStagedFilesResponse = _reflection.GeneratedProtocolMessageType('ListStagedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesResponse)
  })
_sym_db.RegisterMessage(ListStagedFilesResponse)

GetStagedFileRequest = _reflection.GeneratedProtocolMessageType('GetStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileRequest)
  })
_sym_db.RegisterMessage(GetStagedFileRequest)

GetStagedFileResponse = _reflection.GeneratedProtocolMessageType('GetStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileResponse)
  })
_sym_db.RegisterMessage(GetStagedFileResponse)

CreateStagedFileRequest = _reflection.GeneratedProtocolMessageType('CreateStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileRequest)
  })
_sym_db.RegisterMessage(CreateStagedFileRequest)

CreateStagedFileResponse = _reflection.GeneratedProtocolMessageType('CreateStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileResponse)
  })
_sym_db.RegisterMessage(CreateStagedFileResponse)

_STAGEDFILESERVICE = DESCRIPTOR.services_by_name['StagedFileService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\017StagedFileProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _STAGEDFILE.fields_by_name['file_id']._options = None
  _STAGEDFILE.fields_by_name['file_id']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['file_name']._options = None
  _STAGEDFILE.fields_by_name['file_name']._serialized_options = b'\372B\004r\002\020\001'
  _STAGEDFILE.fields_by_name['create_time']._options = None
  _STAGEDFILE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['upload_completed_time']._options = None
  _STAGEDFILE.fields_by_name['upload_completed_time']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['content_id']._options = None
  _STAGEDFILE.fields_by_name['content_id']._serialized_options = b'\372B\010r\006\230\001 \320\001\001'
  _STAGEDFILE.fields_by_name['content_length']._options = None
  _STAGEDFILE.fields_by_name['content_length']._serialized_options = b'\340A\003'
  _STAGEDFILE.fields_by_name['schema']._options = None
  _STAGEDFILE.fields_by_name['schema']._serialized_options = b'\340A\003'
  _LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._options = None
  _LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETSTAGEDFILEREQUEST.fields_by_name['file_id']._options = None
  _GETSTAGEDFILEREQUEST.fields_by_name['file_id']._serialized_options = b'\372B\004r\002\020\001'
  _CREATESTAGEDFILEREQUEST.fields_by_name['file']._options = None
  _CREATESTAGEDFILEREQUEST.fields_by_name['file']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STAGEDFILESERVICE.methods_by_name['ListStagedFiles']._options = None
  _STAGEDFILESERVICE.methods_by_name['ListStagedFiles']._serialized_options = b'\202\323\344\223\002\027\022\025/v1alpha/staged_files'
  _STAGEDFILESERVICE.methods_by_name['GetStagedFile']._options = None
  _STAGEDFILESERVICE.methods_by_name['GetStagedFile']._serialized_options = b'\202\323\344\223\002#\022!/v1alpha/staged_files/{file_id=*}'
  _STAGEDFILESERVICE.methods_by_name['CreateStagedFile']._options = None
  _STAGEDFILESERVICE.methods_by_name['CreateStagedFile']._serialized_options = b'\202\323\344\223\002\035:\004file\"\025/v1alpha/staged_files'
  _STAGEDFILE._serialized_start=253
  _STAGEDFILE._serialized_end=631
  _LISTSTAGEDFILESREQUEST._serialized_start=633
  _LISTSTAGEDFILESREQUEST._serialized_end=753
  _LISTSTAGEDFILESRESPONSE._serialized_start=756
  _LISTSTAGEDFILESRESPONSE._serialized_end=954
  _GETSTAGEDFILEREQUEST._serialized_start=956
  _GETSTAGEDFILEREQUEST._serialized_end=1012
  _GETSTAGEDFILERESPONSE._serialized_start=1015
  _GETSTAGEDFILERESPONSE._serialized_end=1169
  _CREATESTAGEDFILEREQUEST._serialized_start=1171
  _CREATESTAGEDFILEREQUEST._serialized_end=1259
  _CREATESTAGEDFILERESPONSE._serialized_start=1262
  _CREATESTAGEDFILERESPONSE._serialized_end=1437
  _STAGEDFILESERVICE._serialized_start=1440
  _STAGEDFILESERVICE._serialized_end=1900
# @@protoc_insertion_point(module_scope)
