# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/fenl/v1alpha/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!kaskada/fenl/v1alpha/schema.proto\x12\x14kaskada.fenl.v1alpha\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x07\n\x08\x44\x61taType\x12L\n\tprimitive\x18\x01 \x01(\x0e\x32,.kaskada.fenl.v1alpha.DataType.PrimitiveTypeH\x00R\tprimitive\x12\x36\n\x06struct\x18\x02 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaH\x00R\x06struct\x12\x30\n\x06window\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x06window\"\x90\x06\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13PRIMITIVE_TYPE_NULL\x10\x01\x12\x17\n\x13PRIMITIVE_TYPE_BOOL\x10\x02\x12\x15\n\x11PRIMITIVE_TYPE_I8\x10\x03\x12\x16\n\x12PRIMITIVE_TYPE_I16\x10\x04\x12\x16\n\x12PRIMITIVE_TYPE_I32\x10\x05\x12\x16\n\x12PRIMITIVE_TYPE_I64\x10\x06\x12\x15\n\x11PRIMITIVE_TYPE_U8\x10\x07\x12\x16\n\x12PRIMITIVE_TYPE_U16\x10\x08\x12\x16\n\x12PRIMITIVE_TYPE_U32\x10\t\x12\x16\n\x12PRIMITIVE_TYPE_U64\x10\n\x12\x16\n\x12PRIMITIVE_TYPE_F16\x10\x0b\x12\x16\n\x12PRIMITIVE_TYPE_F32\x10\x0c\x12\x16\n\x12PRIMITIVE_TYPE_F64\x10\r\x12\x19\n\x15PRIMITIVE_TYPE_STRING\x10\x0e\x12$\n PRIMITIVE_TYPE_INTERVAL_DAY_TIME\x10\x0f\x12&\n\"PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH\x10\x10\x12\"\n\x1ePRIMITIVE_TYPE_DURATION_SECOND\x10\x11\x12\'\n#PRIMITIVE_TYPE_DURATION_MILLISECOND\x10\x12\x12\'\n#PRIMITIVE_TYPE_DURATION_MICROSECOND\x10\x13\x12&\n\"PRIMITIVE_TYPE_DURATION_NANOSECOND\x10\x14\x12#\n\x1fPRIMITIVE_TYPE_TIMESTAMP_SECOND\x10\x15\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND\x10\x16\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND\x10\x17\x12\'\n#PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND\x10\x18\x42\x06\n\x04kind\"\x9e\x01\n\x06Schema\x12:\n\x06\x66ields\x18\x01 \x03(\x0b\x32\".kaskada.fenl.v1alpha.Schema.FieldR\x06\x66ields\x1aX\n\x05\x46ield\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\tdata_type\x18\x02 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\x08\x64\x61taTypeB\xe2\x01\n\x18\x63om.kaskada.fenl.v1alphaB\x0bSchemaProtoP\x01ZGgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha;fenlv1alpha\xa2\x02\x03KFX\xaa\x02\x14Kaskada.Fenl.V1alpha\xca\x02\x14Kaskada\\Fenl\\V1alpha\xe2\x02 Kaskada\\Fenl\\V1alpha\\GPBMetadata\xea\x02\x16Kaskada::Fenl::V1alphab\x06proto3')



_DATATYPE = DESCRIPTOR.message_types_by_name['DataType']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_SCHEMA_FIELD = _SCHEMA.nested_types_by_name['Field']
_DATATYPE_PRIMITIVETYPE = _DATATYPE.enum_types_by_name['PrimitiveType']
DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.DataType)
  })
_sym_db.RegisterMessage(DataType)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_FIELD,
    '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema.Field)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.Field)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.kaskada.fenl.v1alphaB\013SchemaProtoP\001ZGgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha;fenlv1alpha\242\002\003KFX\252\002\024Kaskada.Fenl.V1alpha\312\002\024Kaskada\\Fenl\\V1alpha\342\002 Kaskada\\Fenl\\V1alpha\\GPBMetadata\352\002\026Kaskada::Fenl::V1alpha'
  _DATATYPE._serialized_start=89
  _DATATYPE._serialized_end=1078
  _DATATYPE_PRIMITIVETYPE._serialized_start=286
  _DATATYPE_PRIMITIVETYPE._serialized_end=1070
  _SCHEMA._serialized_start=1081
  _SCHEMA._serialized_end=1239
  _SCHEMA_FIELD._serialized_start=1151
  _SCHEMA_FIELD._serialized_end=1239
# @@protoc_insertion_point(module_scope)
