# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.shared.v1alpha import catalog_pb2 as kaskada_dot_shared_dot_v1alpha_dot_catalog__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fkaskada/api/v1alpha/table.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a$kaskada/shared/v1alpha/catalog.proto\x1a\x17validate/validate.proto\"\xc1\x07\n\x05Table\x12\x1e\n\x08table_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07tableId\x12&\n\ntable_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x31\n\x10time_column_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0etimeColumnName\x12<\n\x16\x65ntity_key_column_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13\x65ntityKeyColumnName\x12\x35\n\x17old_subsort_column_name\x18\x05 \x01(\tR\x14oldSubsortColumnName\x12\x1f\n\x0bgrouping_id\x18\x07 \x01(\tR\ngroupingId\x12@\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x1d\n\x07version\x18\n \x01(\x03\x42\x03\xe0\x41\x03R\x07version\x12\x39\n\x06schema\x18\r \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x03\xe0\x41\x03R\x06schema\x12\"\n\nfile_count\x18\x0e \x01(\x03\x42\x03\xe0\x41\x03R\tfileCount\x12U\n\x13subsort_column_name\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x07\xfa\x42\x04r\x02\x10\x01R\x11subsortColumnName\x12\x44\n\x07kaskada\x18\x10 \x01(\x0b\x32(.kaskada.api.v1alpha.Table.KaskadaSourceH\x00R\x07kaskada\x12\x44\n\x07iceberg\x18\x11 \x01(\x0b\x32(.kaskada.api.v1alpha.Table.IcebergSourceH\x00R\x07iceberg\x1a\x0f\n\rKaskadaSource\x1a\x94\x01\n\rIcebergSource\x12=\n\x06\x63onfig\x18\x01 \x01(\x0b\x32%.kaskada.shared.v1alpha.CatalogConfigR\x06\x63onfig\x12%\n\tnamespace\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\tnamespace\x12\x1d\n\ntable_name\x18\x03 \x01(\tR\ttableNameB\x08\n\x06sourceJ\x04\x08\x06\x10\x07J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\r\"\x94\x02\n\x13TableVersionDetails\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12@\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x1b\n\x06schema\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x06schema\x12P\n\nfile_infos\x18\x05 \x03(\x0b\x32\x31.kaskada.api.v1alpha.TableVersionDetails.FileInfoR\tfileInfos\x1a,\n\x08\x46ileInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03key\x18\x02 \x01(\tR\x03keyJ\x04\x08\x04\x10\x05\"s\n\x11ListTablesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xbe\x01\n\x12ListTablesResponse\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"9\n\x0fGetTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x92\x01\n\x10GetTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"P\n\x12\x43reateTableRequest\x12:\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05table\"\x95\x01\n\x13\x43reateTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"R\n\x12\x44\x65leteTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"\x87\x01\n\x13\x44\x65leteTableResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"\xb8\x02\n\x0fLoadDataRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\"\n\x07\x66ile_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x06\x66ileId\x12O\n\x10\x65xternal_s3_file\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.ExternalS3FileH\x00R\x0e\x65xternalS3File\x12\x61\n\x10refresh_external\x18\x04 \x01(\x0b\x32\x34.kaskada.api.v1alpha.LoadDataRequest.RefreshExternalH\x00R\x0frefreshExternal\x1a\x11\n\x0fRefreshExternalB\x12\n\x0bsource_data\x12\x03\xf8\x42\x01\"\x84\x01\n\x10LoadDataResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x94\x05\n\x0cTableService\x12v\n\nListTables\x12&.kaskada.api.v1alpha.ListTablesRequest\x1a\'.kaskada.api.v1alpha.ListTablesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/tables\x12\x7f\n\x08GetTable\x12$.kaskada.api.v1alpha.GetTableRequest\x1a%.kaskada.api.v1alpha.GetTableResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/tables/{table_name=*}\x12\x80\x01\n\x0b\x43reateTable\x12\'.kaskada.api.v1alpha.CreateTableRequest\x1a(.kaskada.api.v1alpha.CreateTableResponse\"\x1e\x82\xd3\xe4\x93\x02\x18:\x05table\"\x0f/v1alpha/tables\x12\x88\x01\n\x0b\x44\x65leteTable\x12\'.kaskada.api.v1alpha.DeleteTableRequest\x1a(.kaskada.api.v1alpha.DeleteTableResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/tables/{table_name=*}\x12}\n\x08LoadData\x12$.kaskada.api.v1alpha.LoadDataRequest\x1a%.kaskada.api.v1alpha.LoadDataResponse\"$\x82\xd3\xe4\x93\x02\x1e:\x01*\"\x19/v1alpha/tables/load_dataB\xda\x01\n\x17\x63om.kaskada.api.v1alphaB\nTableProtoP\x01ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\xa2\x02\x03KAX\xaa\x02\x13Kaskada.Api.V1alpha\xca\x02\x13Kaskada\\Api\\V1alpha\xe2\x02\x1fKaskada\\Api\\V1alpha\\GPBMetadata\xea\x02\x15Kaskada::Api::V1alphab\x06proto3')



_TABLE = DESCRIPTOR.message_types_by_name['Table']
_TABLE_KASKADASOURCE = _TABLE.nested_types_by_name['KaskadaSource']
_TABLE_ICEBERGSOURCE = _TABLE.nested_types_by_name['IcebergSource']
_TABLEVERSIONDETAILS = DESCRIPTOR.message_types_by_name['TableVersionDetails']
_TABLEVERSIONDETAILS_FILEINFO = _TABLEVERSIONDETAILS.nested_types_by_name['FileInfo']
_LISTTABLESREQUEST = DESCRIPTOR.message_types_by_name['ListTablesRequest']
_LISTTABLESRESPONSE = DESCRIPTOR.message_types_by_name['ListTablesResponse']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_CREATETABLEREQUEST = DESCRIPTOR.message_types_by_name['CreateTableRequest']
_CREATETABLERESPONSE = DESCRIPTOR.message_types_by_name['CreateTableResponse']
_DELETETABLEREQUEST = DESCRIPTOR.message_types_by_name['DeleteTableRequest']
_DELETETABLERESPONSE = DESCRIPTOR.message_types_by_name['DeleteTableResponse']
_LOADDATAREQUEST = DESCRIPTOR.message_types_by_name['LoadDataRequest']
_LOADDATAREQUEST_REFRESHEXTERNAL = _LOADDATAREQUEST.nested_types_by_name['RefreshExternal']
_LOADDATARESPONSE = DESCRIPTOR.message_types_by_name['LoadDataResponse']
Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {

  'KaskadaSource' : _reflection.GeneratedProtocolMessageType('KaskadaSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_KASKADASOURCE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table.KaskadaSource)
    })
  ,

  'IcebergSource' : _reflection.GeneratedProtocolMessageType('IcebergSource', (_message.Message,), {
    'DESCRIPTOR' : _TABLE_ICEBERGSOURCE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table.IcebergSource)
    })
  ,
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table)
  })
_sym_db.RegisterMessage(Table)
_sym_db.RegisterMessage(Table.KaskadaSource)
_sym_db.RegisterMessage(Table.IcebergSource)

TableVersionDetails = _reflection.GeneratedProtocolMessageType('TableVersionDetails', (_message.Message,), {

  'FileInfo' : _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
    'DESCRIPTOR' : _TABLEVERSIONDETAILS_FILEINFO,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails.FileInfo)
    })
  ,
  'DESCRIPTOR' : _TABLEVERSIONDETAILS,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails)
  })
_sym_db.RegisterMessage(TableVersionDetails)
_sym_db.RegisterMessage(TableVersionDetails.FileInfo)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DeleteTableRequest = _reflection.GeneratedProtocolMessageType('DeleteTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableRequest)
  })
_sym_db.RegisterMessage(DeleteTableRequest)

DeleteTableResponse = _reflection.GeneratedProtocolMessageType('DeleteTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableResponse)
  })
_sym_db.RegisterMessage(DeleteTableResponse)

LoadDataRequest = _reflection.GeneratedProtocolMessageType('LoadDataRequest', (_message.Message,), {

  'RefreshExternal' : _reflection.GeneratedProtocolMessageType('RefreshExternal', (_message.Message,), {
    'DESCRIPTOR' : _LOADDATAREQUEST_REFRESHEXTERNAL,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest.RefreshExternal)
    })
  ,
  'DESCRIPTOR' : _LOADDATAREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest)
  })
_sym_db.RegisterMessage(LoadDataRequest)
_sym_db.RegisterMessage(LoadDataRequest.RefreshExternal)

LoadDataResponse = _reflection.GeneratedProtocolMessageType('LoadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATARESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataResponse)
  })
_sym_db.RegisterMessage(LoadDataResponse)

_TABLESERVICE = DESCRIPTOR.services_by_name['TableService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.kaskada.api.v1alphaB\nTableProtoP\001ZEgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/api/v1alpha;apiv1alpha\242\002\003KAX\252\002\023Kaskada.Api.V1alpha\312\002\023Kaskada\\Api\\V1alpha\342\002\037Kaskada\\Api\\V1alpha\\GPBMetadata\352\002\025Kaskada::Api::V1alpha'
  _TABLE_ICEBERGSOURCE.fields_by_name['namespace']._options = None
  _TABLE_ICEBERGSOURCE.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['table_id']._options = None
  _TABLE.fields_by_name['table_id']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['table_name']._options = None
  _TABLE.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['time_column_name']._options = None
  _TABLE.fields_by_name['time_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['entity_key_column_name']._options = None
  _TABLE.fields_by_name['entity_key_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLE.fields_by_name['create_time']._options = None
  _TABLE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['update_time']._options = None
  _TABLE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['version']._options = None
  _TABLE.fields_by_name['version']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['schema']._options = None
  _TABLE.fields_by_name['schema']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['file_count']._options = None
  _TABLE.fields_by_name['file_count']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['subsort_column_name']._options = None
  _TABLE.fields_by_name['subsort_column_name']._serialized_options = b'\372B\004r\002\020\001'
  _TABLEVERSIONDETAILS.fields_by_name['create_time']._options = None
  _TABLEVERSIONDETAILS.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLEVERSIONDETAILS.fields_by_name['schema']._options = None
  _TABLEVERSIONDETAILS.fields_by_name['schema']._serialized_options = b'\340A\003'
  _LISTTABLESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLESREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\007\032\005\030\350\007(\000'
  _GETTABLEREQUEST.fields_by_name['table_name']._options = None
  _GETTABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATETABLEREQUEST.fields_by_name['table']._options = None
  _CREATETABLEREQUEST.fields_by_name['table']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETETABLEREQUEST.fields_by_name['table_name']._options = None
  _DELETETABLEREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOADDATAREQUEST.oneofs_by_name['source_data']._options = None
  _LOADDATAREQUEST.oneofs_by_name['source_data']._serialized_options = b'\370B\001'
  _LOADDATAREQUEST.fields_by_name['table_name']._options = None
  _LOADDATAREQUEST.fields_by_name['table_name']._serialized_options = b'\372B\004r\002\020\001'
  _LOADDATAREQUEST.fields_by_name['file_id']._options = None
  _LOADDATAREQUEST.fields_by_name['file_id']._serialized_options = b'\372B\004r\002\020\001'
  _TABLESERVICE.methods_by_name['ListTables']._options = None
  _TABLESERVICE.methods_by_name['ListTables']._serialized_options = b'\202\323\344\223\002\021\022\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['GetTable']._options = None
  _TABLESERVICE.methods_by_name['GetTable']._serialized_options = b'\202\323\344\223\002 \022\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['CreateTable']._options = None
  _TABLESERVICE.methods_by_name['CreateTable']._serialized_options = b'\202\323\344\223\002\030:\005table\"\017/v1alpha/tables'
  _TABLESERVICE.methods_by_name['DeleteTable']._options = None
  _TABLESERVICE.methods_by_name['DeleteTable']._serialized_options = b'\202\323\344\223\002 *\036/v1alpha/tables/{table_name=*}'
  _TABLESERVICE.methods_by_name['LoadData']._options = None
  _TABLESERVICE.methods_by_name['LoadData']._serialized_options = b'\202\323\344\223\002\036:\001*\"\031/v1alpha/tables/load_data'
  _TABLE._serialized_start=346
  _TABLE._serialized_end=1307
  _TABLE_KASKADASOURCE._serialized_start=1113
  _TABLE_KASKADASOURCE._serialized_end=1128
  _TABLE_ICEBERGSOURCE._serialized_start=1131
  _TABLE_ICEBERGSOURCE._serialized_end=1279
  _TABLEVERSIONDETAILS._serialized_start=1310
  _TABLEVERSIONDETAILS._serialized_end=1586
  _TABLEVERSIONDETAILS_FILEINFO._serialized_start=1536
  _TABLEVERSIONDETAILS_FILEINFO._serialized_end=1580
  _LISTTABLESREQUEST._serialized_start=1588
  _LISTTABLESREQUEST._serialized_end=1703
  _LISTTABLESRESPONSE._serialized_start=1706
  _LISTTABLESRESPONSE._serialized_end=1896
  _GETTABLEREQUEST._serialized_start=1898
  _GETTABLEREQUEST._serialized_end=1955
  _GETTABLERESPONSE._serialized_start=1958
  _GETTABLERESPONSE._serialized_end=2104
  _CREATETABLEREQUEST._serialized_start=2106
  _CREATETABLEREQUEST._serialized_end=2186
  _CREATETABLERESPONSE._serialized_start=2189
  _CREATETABLERESPONSE._serialized_end=2338
  _DELETETABLEREQUEST._serialized_start=2340
  _DELETETABLEREQUEST._serialized_end=2422
  _DELETETABLERESPONSE._serialized_start=2425
  _DELETETABLERESPONSE._serialized_end=2560
  _LOADDATAREQUEST._serialized_start=2563
  _LOADDATAREQUEST._serialized_end=2875
  _LOADDATAREQUEST_REFRESHEXTERNAL._serialized_start=2838
  _LOADDATAREQUEST_REFRESHEXTERNAL._serialized_end=2855
  _LOADDATARESPONSE._serialized_start=2878
  _LOADDATARESPONSE._serialized_end=3010
  _TABLESERVICE._serialized_start=3013
  _TABLESERVICE._serialized_end=3673
# @@protoc_insertion_point(module_scope)
